Bug 1308648 - Fix reference to ./mach devtools-css-db in test_css-properties.js; r?tromey draft
authorGreg Tatum <tatum.creative@gmail.com>
Mon, 10 Oct 2016 09:11:53 -0500
changeset 423216 79b8273398767a439a60d4f1b611ca2d25932728
parent 423199 7be6b348c431d69f96f0765af3a0c0a0fe56d4bf
child 533385 1ab9e796332ec298c1ef6dcbd1146028351cdf20
push id31826
push userbmo:gtatum@mozilla.com
push dateMon, 10 Oct 2016 14:17:45 +0000
reviewerstromey
bugs1308648
milestone52.0a1
Bug 1308648 - Fix reference to ./mach devtools-css-db in test_css-properties.js; r?tromey MozReview-Commit-ID: 7zk80TVehlV
devtools/shared/tests/unit/test_css-properties-db.js
--- a/devtools/shared/tests/unit/test_css-properties-db.js
+++ b/devtools/shared/tests/unit/test_css-properties-db.js
@@ -1,14 +1,14 @@
 /* Any copyright is dedicated to the Public Domain.
    http://creativecommons.org/publicdomain/zero/1.0/ */
 
 /**
  * Test that the devtool's client-side CSS properties database is in sync with the values
  * on the platform. If they are not, then `mach generate-css-db` needs to be run to
  * make everything up to date. Nightly, aurora, beta, and release may have different
  * preferences for what CSS values are enabled. The static CSS properties database can
  * be slightly different from the target platform as long as there is a preference that
  * exists that turns off that CSS property.
  */
 
 "use strict";
 
@@ -18,17 +18,17 @@ const DOMUtils = Components.classes["@mo
 const {PSEUDO_ELEMENTS, CSS_PROPERTIES, PREFERENCES} = require("devtools/shared/css/generated/properties-db");
 const {generateCssProperties} = require("devtools/server/actors/css-properties");
 const { Preferences } = require("resource://gre/modules/Preferences.jsm");
 
 function run_test() {
   const propertiesErrorMessage = "If this assertion fails, then the client side CSS " +
                                  "properties list in devtools is out of sync with the " +
                                  "CSS properties on the platform. To fix this " +
-                                 "assertion run `mach generate-css-db` to re-generate " +
+                                 "assertion run `mach devtools-css-db` to re-generate " +
                                  "the client side properties.";
 
   // Check that the platform and client match for pseudo elements.
@@ -1,14 +1,14 @@
 /**
  * Test that the devtool's client-side CSS properties database is in sync with the values
- * on the platform. If they are not, then `mach generate-css-db` needs to be run to
+ * on the platform. If they are not, then `mach devtools-css-db` needs to be run to
  * make everything up to date. Nightly, aurora, beta, and release may have different
  * preferences for what CSS values are enabled. The static CSS properties database can
   deepEqual(PSEUDO_ELEMENTS, DOMUtils.getCSSPseudoElementNames(), `The pseudo elements ` +
             `match on the client and platform. ${propertiesErrorMessage}`);
 
   /**
    * Check that the platform and client match for the details on their CSS properties.